#------ these parameters need to be changed depending on lcuster
outdir = "./scratch/"
pseudo_dir = "./"
home_bashrc = "~/.bashrc"
submission_command = "bash"  # could be qsub, mysub, sbatch, etc

OMP_NUM_THREADS = 1
modules = []

parallel = 'mpirun'
#---------------------------------------------------------------
